import { IFunctionScanResult } from './types';
import * as Decl from '../parser/models/declare';
import * as Expr from '../parser/models/expr';
import * as Stmt from '../parser/models/stmt';
import { TreeTraverse } from '../utilities/treeTraverse';
/**
 * Class to help identify parameters and return statements in
 * a kerboscript function
 */
export declare class FunctionScan extends TreeTraverse {
    /**
     * result of the scan
     */
    private result;
    /**
     * Function scan constructor
     */
    constructor();
    /**
     * Scan the function node for parameters and return statements
     * @param node function body
     */
    scan(node: Stmt.Block): IFunctionScanResult;
    /**
     * Indicate that the function has a return statement
     * @param _ return statement
     */
    visitReturn(_: Stmt.Return): void;
    /**
     * Don't proceed further in if enter another function
     * @param _ function declaration
     */
    visitDeclFunction(_: Decl.Func): void;
    /**
     * Add required and optional parameters when found
     * @param decl parameter declaration
     */
    visitDeclParameter(decl: Decl.Param): void;
    /**
     * Don't proceed further if another lambda is encountered
     * @param expr lambda expression
     */
    visitLambda(_: Expr.Lambda): void;
}
