import { KsBaseSymbol, KsSymbolKind } from '../types';
import { BasicTracker } from './tracker';
import { KsVariable } from '../../models/variable';
import { KsParameter } from '../../models/parameter';
import { KsFunction } from '../../models/function';
import { KsLock } from '../../models/lock';
declare type TrackerKind<T extends KsSymbolKind> = T extends KsSymbolKind.variable | KsSymbolKind.parameter ? BasicTracker<KsVariable | KsParameter> : BasicTracker<KsFunction | KsLock>;
/**
 * A scope class that contains symbols in the current scope
 */
export declare class Environment {
    private varTable;
    private funcTable;
    constructor();
    /**
     * Get a value from the environment, first functions then variables
     * @param key key lookup
     */
    get(key: string): Maybe<BasicTracker>;
    /**
     * Get a value from the environment, functions or variables
     * @param key key lookup
     */
    getKind(key: string, kind: KsSymbolKind): Maybe<BasicTracker>;
    /**
     * See if an environment has a value, first functions then variables
     * @param key key lookup
     */
    has(key: string): boolean;
    /**
     * See if an environment has a value, functions or variables
     * @param key key lookup
     */
    hasKind(key: string, kind: KsSymbolKind): boolean;
    /**
     * Set a value to the environment
     * @param key key lookup
     * @param value basic tracker
     */
    set<TKind extends KsSymbolKind>(key: string, kind: TKind, value: TrackerKind<TKind>): Map<string, BasicTracker<KsBaseSymbol>>;
    /**
     * Get all trackers in this environment
     */
    trackers(): BasicTracker[];
    /**
     * All the symbols in this environment
     */
    symbols(): KsBaseSymbol[];
}
export {};
