import { SymbolTrackerBase, KsSet, IKsDeclared, TrackerKind, KsBaseSymbol } from '../types';
import { Location } from 'vscode-languageserver';
import { IType } from '../../typeChecker/types';
export declare class BasicTracker<T extends KsBaseSymbol = KsBaseSymbol> implements SymbolTrackerBase {
    uri: string;
    type: IType;
    readonly declared: IKsDeclared<T, IType>;
    /**
     * Information about locations where the this symbol was set
     */
    readonly sets: KsSet[];
    /**
     * Locations where this symbol was used
     */
    readonly usages: Location[];
    constructor(symbol: T, uri: string, type?: IType);
    /**
     * What kind of tracker is this type
     */
    get kind(): TrackerKind.basic;
    /**
     * Set the declared type of this symbol
     * @param type type to declare this symbol
     */
    declareType(type: IType): void;
    /**
     * Get the type at a location
     * @param loc query location
     */
    getType(loc: Location): Maybe<IType>;
    /**
     * Set the type at a location
     * @param loc location to set
     * @param type type to set
     */
    setType(loc: Location, type: IType): void;
}
/**
 * Create a set symbol
 * @param loc location to create the set
 * @param type type of this set
 */
export declare const createSymbolSet: (loc: Location, type?: IType) => KsSet;
