import { LintRule } from './models/lintRules';
import { DiagnosticSeverity, Diagnostic } from 'vscode-languageserver';
/**
 * A class to manager how and when rules should be applied to diagnostics
 */
export declare class LintManager {
    /**
     * What severity should a diagnostic be reported as
     */
    readonly codeSeverities: Map<string, DiagnosticSeverity>;
    /**
     * What codes are associated with the config
     */
    readonly configCodes: Set<string>;
    /**
     * Construct a new LintManager
     * @param severities
     */
    constructor(severities: Map<string, DiagnosticSeverity>, configRules: Set<string>);
    /**
     * Apply the current lint settings to the provided diagnostics
     * @param diagnostics diagnostics to update
     */
    apply<T extends Diagnostic>(diagnostics: T[]): T[];
    /**
     * Create a lint manager from a set of lint rules
     * @param rules line rules to create diagnostic manager from
     */
    static fromRules(rules: LintRule[], configCodes: Set<string>): LintManager;
}
