import { DiagnosticSeverity } from 'vscode-languageserver';
import { DIAGNOSTICS } from '../../utilities/diagnosticsUtils';
/**
 * A class for holding information about a lint rule in kos-language-server
 */
export declare class LintRule {
    /**
     * The name of the rule
     */
    readonly rule: string;
    /**
     * What level should this rule by reported as
     */
    readonly level: SettableSeverity;
    /**
     * What diagnostics fall under this linter rule
     */
    readonly diagnostics: ValueOf<typeof DIAGNOSTICS>[];
    /**
     * Are any rules owned by this rule
     */
    readonly owned: LintRule[];
    /**
     * Construct a new lint rule
     * @param rule what is the name of the rule
     * @param level what level should this rule be applied
     * @param diagnostics what diagnostics fall under
     * @param owned what rules are owned by this this rule
     */
    constructor(rule: string, level: SettableSeverity, diagnostics: ValueOf<typeof DIAGNOSTICS>[], owned: LintRule[]);
    /**
     * Create a rule from another rule
     * @param lintRule rule to clone from
     */
    static from({ rule, level, diagnostics, owned }: LintRule): LintRule;
}
/**
 * Settable severity
 */
export declare type SettableSeverity = 'error' | 'warning' | 'info' | 'hint' | 'off';
/**
 * Map from settable severity to diagnostic severity
 */
export declare const severityMapper: Map<string, DiagnosticSeverity>;
export declare const lintCategories: LintRule[];
export declare const lintRules: Map<string, LintRule>;
