import { ClientConfiguration, IClientCapabilities } from '../../types';
import { URI } from 'vscode-uri';
export declare class ServerConfiguration {
    /**
     * What system path corresponds to the root of the workspace
     */
    readonly workspaceFolder?: string;
    /**
     * What Uri corresponds to the root of the workspace
     */
    readonly workspaceUri?: URI;
    /**
     * The client configurations for the language server
     */
    readonly clientConfig: ClientConfiguration;
    /**
     * What are the client capabilities in terms of the language
     * server protocol
     */
    readonly clientCapability: IClientCapabilities;
    /**
     * Construct a new server configuration
     * @param workspaceFolder workspace folder
     * @param workspaceUri workspace uri
     * @param clientConfig client configuration for the server
     * @param clientCapability client lsp configuration
     */
    constructor(clientConfig: ClientConfiguration, clientCapability: IClientCapabilities, workspaceFolder?: string, workspaceUri?: URI);
    /**
     * Merge a partial server configuration into this configuration
     * @param config partial server configuration
     */
    merge(config: Partial<ServerConfiguration>): ServerConfiguration;
    /**
     * Is this server config equal to another?
     * @param other other configuration
     */
    equal(other: ServerConfiguration): boolean;
}
/**
 * The default client side kls configuration
 */
export declare const defaultClientConfiguration: ClientConfiguration;
/**
 * The default server side kls configuration
 */
export declare const defaultServerConfiguration: ServerConfiguration;
