import { LintRule } from './lintRules';
import { URI } from 'vscode-uri';
/**
 * Class representing a ksconfig.json file. This is used to specify
 * configurations for this workspace
 */
export declare class WorkspaceConfiguration {
    /**
     * The location of the workspace config
     */
    configDirectoryUri?: URI;
    /**
     * The location of the root volume (volume 0)
     */
    readonly rootVolumePath?: string;
    /**
     * The name of any custom bodies used i.e. modded
     */
    readonly bodies?: string[];
    /**
     * These are the lint rules enabled and at what level
     */
    readonly lintRules?: Map<string, LintRule>;
    /**
     * Construct a new configuration
     * @param rootVolumePath root volume
     * @param bodies custom bodies
     * @param lintRules lint rules in place
     */
    constructor(configDirectoryUri?: URI, rootVolumePath?: string, bodies?: string[], lintRules?: Map<string, LintRule>);
    /**
     * What is the location of the root volume
     */
    rootVolumeUri(): Maybe<URI>;
    /**
     * Merge this configuration with another
     * @param config config to merge into this one
     */
    merge(config: WorkspaceConfiguration): WorkspaceConfiguration;
    /**
     * Is this workspace configuration equal to another
     * @param other other workspace configuration to compare to
     */
    equal(other: WorkspaceConfiguration): boolean;
}
/**
 * The default configuration workspace configuration
 */
export declare const defaultWorkspaceConfiguration: WorkspaceConfiguration;
