import { Boundary } from './types';
import { Diagnostic } from 'vscode-languageserver';
import { BasicBlock } from './models/basicBlock';
/**
 * A class representing the control flow graph through a script.
 */
export declare class FlowGraph {
    /**
     * entrance and exit blocks to the script
     */
    readonly script: Boundary;
    /**
     * entrance and exit blocks to each function in the script
     */
    readonly functions: Boundary[];
    /**
     * entrance and exit blocks to each trigger in the script
     */
    readonly triggers: Boundary[];
    /**
     * All the nodes in this script
     */
    readonly nodes: BasicBlock[];
    /**
     * A graph of the whole flow
     */
    private readonly graph;
    /**
     * construct a new flow graph
     * @param script script boundary
     * @param functions function boundaries
     * @param triggers trigger boundaries
     */
    constructor(script: Boundary, functions: Boundary[], triggers: Boundary[], nodes: BasicBlock[]);
    reachable(): Diagnostic[];
}
