import { BlockKind } from '../types';
import { BranchJump } from './branchJump';
import { IStmt, IExpr } from '../../parser/types';
/**
 * A sequence of expressions of statements representing a basic block with no jumps
 */
export declare class BasicBlock implements GraphNode<BasicBlock> {
    readonly stmt: Maybe<IStmt>;
    /**
     * What is the sequence of nodes executed in this basic block
     */
    readonly exprs: IExpr[];
    /**
     * What kind of block is this block
     */
    readonly kind: BlockKind;
    /**
     * What are the jumps available in this basic block
     */
    private jump;
    /**
     * Construct a new basic block
     */
    constructor(kind: BlockKind, stmt?: IStmt);
    /**
     * Add a jump to this basic block
     * @param jump jump to add
     */
    addJump(jump: BasicBlock | BranchJump): void;
    /**
     * Get the current jump
     */
    getJumps(): Maybe<BasicBlock | BranchJump>;
    /**
     * Implement graph interface. WHat is the node value
     */
    value(): BasicBlock;
    /**
     * Implement the graph interface. What are the adjacent node
     */
    adjacentNodes(): GraphNode<BasicBlock>[];
}
