import { BasicBlock } from './basicBlock';
import { IExpr } from '../../parser/types';
import { ReachableJumps } from '../types';
import { Narrowing } from './narrowing';
/**
 * A class representing control from through a branch jump
 */
export declare class BranchJump {
    /**
     * What was the condition associated with this jump
     */
    readonly condition: IExpr;
    /**
     * What is the basic block associated the true branch
     */
    readonly trueBlock: BasicBlock;
    /**
     * What is the basic block associated the false branch
     */
    readonly falseBlock: BasicBlock;
    /**
     * what branches are reachable
     */
    reachable: ReachableJumps;
    /**
     * What narrowings are applied on the true branch
     */
    narrowings: Narrowing[];
    /**
     * Construct a new branch jump
     * @param condition the condition associated with the branch
     * @param trueBlock the true basic block
     * @param falseBlock the false basic block
     */
    constructor(condition: IExpr, trueBlock: BasicBlock, falseBlock: BasicBlock);
}
