import { BasicBlock } from './models/basicBlock';
/**
 * Block kinds for basic blocks
 */
export declare const enum BlockKind {
    /**
     * The entrance to a script
     */
    scriptEntry = 0,
    /**
     * The exit of a script
     */
    scriptExit = 1,
    /**
     * The standard basic block
     */
    basic = 2,
    /**
     * The entrance to an unknown block, either a function or trigger
     */
    unknownEntry = 3,
    /**
     * The exit to an unknown block, either a function or trigger
     */
    unknownExit = 4,
    /**
     * A fake entrance to an unreachable block
     */
    unreachableEntry = 5
}
/**
 * Current return context
 */
export declare const enum ReturnContext {
    /**
     * The return context a function
     */
    function = 0,
    /**
     * THe return context is a trigger
     */
    trigger = 1
}
export declare const enum ReachableJumps {
    /**
     * Both branches of a jump are reachable
     */
    both = 0,
    /**
     * Only the true branch is reachable
     */
    true = 1,
    /**
     * Only the false branch is reachable
     */
    false = 2
}
/**
 * Indicates the boundary of a region with entrance and exit blocks
 */
export interface Boundary {
    /**
     * entry block into this boundary
     */
    entry: BasicBlock;
    /**
     * exit block of this boundary
     */
    exit: BasicBlock;
}
