/**
 * a class representing a graph
 */
export declare class Graph<T> {
    /**
     * the nodes within the graph
     */
    readonly nodes: Set<T>;
    /**
     * The edges present within this graph
     */
    private outEdges;
    /**
     * The reverse of the edges present in the graph
     */
    private inEdges;
    /**
     * Construct a new graph
     * @param nodes nodes in this graph
     */
    constructor(...nodes: T[]);
    /**
     * Add a node to this graph
     */
    addNode(node: T): boolean;
    /**
     * Remove a node from this graph
     * @param node
     */
    removeNode(node: T): boolean;
    /**
     * How many nodes are in the graph
     */
    nodeCount(): number;
    /**
     * Is this node is in the graph
     * @param node node to check
     */
    hasNode(node: T): boolean;
    /**
     * What are nodes that act as sources in this graph
     */
    sources(): T[];
    /**
     * What are nodes that act as sources in this graph
     */
    sinks(): T[];
    /**
     * Add a new edge between the two nodes
     * @param source the source node
     * @param sink the sink node
     */
    addEdge(source: T, sink: T): boolean;
    /**
     * Remove an edge between two nodes
     * @param source the source node
     * @param sink the sink node
     */
    removeEdge(source: T, sink: T): boolean;
    /**
     * Get the edges from this node
     * @param node node to retrieve edges
     */
    getEdges(node: T): Maybe<Set<T>>;
    /**
     * Mirror the graph with reversed edges
     */
    transpose(): Graph<T>;
    /**
     * Add the sets for each edge map
     * @param node node to initialize edges
     */
    private initEdges;
    /**
     * Remove all edges associated with the node
     * @param node node to remove edges to
     */
    private removeNodeEdges;
    /**
     * Create a graph from a collection of nodes
     * @param nodes nodes to construct graph from
     */
    static fromNodes<T>(nodes: GraphNode<T>[]): Graph<T>;
}
