import { Graph } from './graph';
/**
 * Represents the strongly connected components of a graph
 */
export declare class StronglyConnectedComponent<T> {
    /**
     * Is the graph acyclic
     */
    readonly acyclic: boolean;
    /**
     * Original graph
     */
    readonly graph: Graph<T>;
    /**
     * A map from each node to it's component
     */
    readonly nodeMap: Map<T, Set<T>>;
    /**
     * The strongly connected components of the graph
     */
    readonly components: Set<T>[];
    /**
     * Construct a new strongly connected components
     * @param acyclic is the graph acyclic
     * @param nodeMap map from nodes to components
     * @param components the components in this graph
     */
    constructor(graph: Graph<T>, nodeMap: Map<T, Set<T>>, components: Set<T>[]);
    /**
     * Create a graph from the strongly connected components
     */
    componentGraph(): Graph<Set<T>>;
    /**
     * Create this from the result
     * @param graph the source graph
     * @param nodeMap node map to components
     */
    static fromResult<T>(graph: Graph<T>, nodeMap: Map<T, Set<T>>, components: Set<T>[]): StronglyConnectedComponent<T>;
}
