import { TokenType } from './tokentypes';
import { Range, Position } from 'vscode-languageserver';
import { TokenBase } from './types';
import { SymbolTracker } from '../analysis/types';
/**
 * Represents  an atomic unit of the kerboscript language
 */
export declare class Token<T extends TokenType = TokenType> implements TokenBase<T> {
    readonly type: T;
    readonly lexeme: string;
    readonly literal: any;
    readonly start: Position;
    readonly end: Position;
    readonly uri: string;
    /**
     * What symbol tracker is this token tied too
     */
    tracker: Maybe<SymbolTracker>;
    constructor(type: T, lexeme: string, literal: any, start: Position, end: Position, uri: string);
    /**
     * A lowercase version of the lexeme for case insensitive comparisons
     */
    get lookup(): string;
    get tag(): 'token';
    get typeString(): string;
    get range(): Range;
    /**
     * Convert the token to a human readable string
     */
    toString(): string;
}
