import { Stmt, Block } from './stmt';
import { IExpr, IStmtVisitor, ScopeKind, NodeDataBuilder } from '../types';
import { TokenType } from '../../models/tokentypes';
import { Range, Position } from 'vscode-languageserver';
import { NodeBase } from './base';
import { Token } from '../../models/token';
export declare abstract class Decl extends Stmt {
    constructor();
}
export declare class Scope extends NodeBase {
    readonly scope?: Token<TokenType> | undefined;
    readonly declare?: Token<TokenType> | undefined;
    constructor(scope?: Token<TokenType> | undefined, declare?: Token<TokenType> | undefined);
    toLines(): string[];
    get ranges(): Range[];
    get start(): Position;
    get end(): Position;
    get type(): ScopeKind;
}
export declare class Var extends Decl {
    readonly identifier: Token;
    readonly toIs: Token;
    readonly value: IExpr;
    readonly scope: Scope;
    constructor(builder: NodeDataBuilder<Var>);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    accept<T extends (...args: any) => any>(visitor: IStmtVisitor<T>, parameters: Parameters<T>): ReturnType<T>;
}
export declare class Lock extends Decl {
    readonly lock: Token;
    readonly identifier: Token;
    readonly to: Token;
    readonly value: IExpr;
    readonly scope?: Scope;
    constructor(builder: NodeDataBuilder<Lock>);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    accept<T extends (...args: any) => any>(visitor: IStmtVisitor<T>, parameters: Parameters<T>): ReturnType<T>;
}
export declare class Func extends Decl {
    readonly functionToken: Token;
    readonly identifier: Token;
    readonly block: Block;
    readonly scope?: Scope;
    constructor(builder: NodeDataBuilder<Func>);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    accept<T extends (...args: any) => any>(visitor: IStmtVisitor<T>, parameters: Parameters<T>): ReturnType<T>;
}
export declare class Param extends Decl {
    readonly parameterToken: Token;
    readonly requiredParameters: Parameter[];
    readonly optionalParameters: DefaultParam[];
    readonly scope?: Scope;
    constructor(builder: NodeDataBuilder<Param>);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    accept<T extends (...args: any) => any>(visitor: IStmtVisitor<T>, parameters: Parameters<T>): ReturnType<T>;
}
export declare class Parameter extends NodeBase {
    readonly identifier: Token;
    constructor(identifier: Token);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    get isKeyword(): boolean;
}
export declare class DefaultParam extends Parameter {
    readonly toIs: Token;
    readonly value: IExpr;
    constructor(identifier: Token, toIs: Token, value: IExpr);
    toLines(): string[];
    get start(): Position;
    get end(): Position;
    get ranges(): Range[];
    get isKeyword(): boolean;
}
