import { TokenType } from '../models/tokentypes';
import { Token } from '../models/token';
import { DirectiveTokens } from '../directives/types';
import { DiagnosticUri } from '../types';
export declare type ITokenMap = Map<string, {
    type: TokenType;
    literal?: any;
}>;
export interface Tokenized {
    tokens: Token[];
    diagnostics: DiagnosticUri[];
    directiveTokens: DirectiveTokens[];
}
/**
 * The results kinda from the scanner
 */
export declare const enum ScanKind {
    /**
     * The scanner encountered whitespace
     */
    Whitespace = 0,
    /**
     * The scanner encountered a token
     */
    Token = 1,
    /**
     * The scanner produced a error diagnostics
     */
    Diagnostic = 2,
    /**
     * The scanner found a directive
     */
    Directive = 3
}
export declare type Result<T, S extends ScanKind> = {
    result: T;
    kind: S;
};
/**
 * A token result
 */
export declare type ScanToken = Result<Token, ScanKind.Token>;
/**
 * A whitespace result
 */
export declare type ScanWhitespace = Result<null, ScanKind.Whitespace>;
/**
 * A diagnostics result
 */
export declare type ScanDiagnostic = Result<DiagnosticUri, ScanKind.Diagnostic>;
/**
 * A directive result
 */
export declare type ScanDirective<T extends TokenType = TokenType> = {
    directive: Token<T>;
    tokens: Token[];
    diagnostics: DiagnosticUri[];
    kind: ScanKind.Directive;
};
export declare type ScanResult = ScanToken | ScanWhitespace | ScanDiagnostic | ScanDirective;
