import * as Stmt from '../parser/models/stmt';
import * as SuffixTerm from '../parser/models/suffixTerm';
import { FoldingRange } from 'vscode-languageserver';
import { TokenType } from '../models/tokentypes';
import { TreeTraverse } from '../utilities/treeTraverse';
import { IScript } from '../parser/types';
import { BasicDirective } from '../directives/basicDirectives';
declare type RegionDirectives = BasicDirective<TokenType.region | TokenType.endRegion>;
/**
 * A service for identifying foldable regions inside a kerboscript
 */
export declare class FoldableService extends TreeTraverse {
    /**
     * result of the scan
     */
    private result;
    /**
     * Construct a foldable service
     */
    constructor();
    /**
     * Find foldable regions within a document info
     * @param script the script ast
     * @param directives the region token throughout the script
     */
    findRegions(script: IScript, directives: RegionDirectives[]): FoldingRange[];
    /**
     * Visit block statements to add to list of foldable regions
     * @param stmt block statement
     */
    visitBlock(stmt: Stmt.Block): void;
    /**
     * Visit call suffix terms to add to list of foldable regions
     * @param call call site
     */
    visitCall(call: SuffixTerm.Call): void;
    /**
     * What are the foldable regions within this document using `\\ #region` and `\\ #endregion`
     * @param regions regions tokens
     */
    private foldableRegions;
}
export {};
