import { URI } from 'vscode-uri';
/**
 * Document interface
 */
export interface Document {
    /**Document
     * The uri of a document
     */
    uri: string;
    /**
     * The text contained within a document
     */
    text: string;
}
/**
 * What kinda of entity is this
 */
export declare enum IoKind {
    /**
     * The io entity is a file
     */
    file = 0,
    /**
     * The io entity is a directory
     */
    directory = 1
}
/**
 * What is the io entity that is found
 */
export interface IoEntity {
    /**
     * What is the uri of this entity
     */
    uri: URI;
    /**
     * WHat is the kind of this entity
     */
    kind: IoKind;
}
/**
 * A small set of functionality for loading files and directory of files
 */
export declare class IoService {
    constructor();
    /**
     * Load a file from a given path
     * @param path the system path
     */
    load(path: string): Promise<string>;
    /**
     * Load a collection of documents from a given directory
     * @param path the path of the directory
     */
    loadDirectory(path: string): AsyncIterableIterator<Document>;
    /**
     * Check if the uri exists. Performs a normalization step in cases of
     * `runPath("0:\script")` where the .ks is omitted
     * @param caller location of caller
     * @param rawPath path provided in a run statement
     */
    exists(uri: URI): Maybe<URI>;
    /**
     * What entities are in the relevant directory
     * @param uri The uri of the request
     */
    statDirectory(uri: URI): IoEntity[];
}
