import { IParametricType, IType, ITypeMappable } from '../types';
/**
 * A class that's responsible for binding type arguments to type
 * parameters of parametric call signatures
 */
export declare class Binder<T extends ITypeMappable> {
    /**
     * A set of type parameters
     */
    readonly typeParameters: Set<IParametricType>;
    /**
     * Cached type application
     */
    applicationCache: Map<Map<IParametricType, IType>, T>;
    /**
     * Construct a new binder
     * @param names names of the types for substituting
     */
    constructor(names: string[]);
    /**
     * Check if the provided replacement are valid
     * @param typeArguments the requested type substitutions
     */
    protected areValidArguments(typeArguments: Map<ITypeMappable, IType>): void;
    /**
     * Get the cached type arguments to preserve reference equality
     * @param typeReplacement placeholder for type subs
     */
    protected getCachedArguments(typeReplacement: Map<IParametricType, IType>): Map<IParametricType, IType>;
    /**
     * Apply type arguments to this type
     * @param type type to make concrete
     * @param typeArguments type replacement
     */
    protected applyToType(type: IParametricType, typeArguments: Map<IParametricType, IType>): IType;
    /**
     * Map type argument from this type to one of it's children
     * @param typeArguments type arguments for this type
     * @param parameterMap mapping of type parameters from a source type to a target type
     */
    protected mapArguments(typeArguments: Map<IParametricType, IType>, parameterMap: Map<IParametricType, IParametricType>): Map<IParametricType, IType>;
}
