import { IParametricCallSignature, IType, ICallSignature, IParametricType, TypeMap } from '../../types';
/**
 * This call represents a call signature for a type with type parameters.
 * This could likely be rolled up into the overarching type classes but
 * allowed some means of separation
 */
export declare class GenericCallSignature implements IParametricCallSignature {
    /**
     * name to fullfil type mappable interface
     */
    readonly name: string;
    /**
     * type parameters mappings to parameters
     */
    private paramMaps?;
    /**
     * type paramter mapping to return
     */
    private returnMaps?;
    /**
     * The call type binder
     */
    private readonly binder;
    /**
     * Construct a new parametric call signature
     * @param typeParameters type parameters to call signature
     */
    constructor(typeParameters: string[]);
    /**
     * Add parameters to this call signature
     * @param paramMaps parameters to add
     */
    addParams(...paramMaps: TypeMap<IParametricType>[]): void;
    /**
     * Add a return type to this call signature
     * @param returnMaps return to add
     */
    addReturn(returnMaps: TypeMap<IParametricType>): void;
    /**
     * Check that the mapping is valid
     * @param typeMap type mapping
     */
    private checkMapping;
    /**
     * Call signature parameters
     */
    params(): IParametricType[];
    /**
     * The required number of parameters
     */
    requiredParams(): number;
    /**
     * Call signature return
     */
    returns(): IParametricType;
    /**
     * Apply type arguments to this call signature
     * @param typeArguments type arguments
     */
    apply(typeArguments: IType | Map<IParametricType, IType>): ICallSignature;
    /**
     * Get the type parameters of this call signature
     */
    getTypeParameters(): IParametricType[];
    /**
     * Get a string representation of this call signature
     */
    toString(): string;
}
