import { ICallSignature, IType, IParametricType } from '../../types';
/**
 * This call represents a call signature for a type. This could likely be rolled up into
 * the overarching type classes but allowed some means of separation
 */
export declare class CallSignature implements ICallSignature {
    /**
     * primarily used as part of the ITypeMappable interface
     */
    readonly name: string;
    /**
     * The type associated with the parameters of this call signature if any
     */
    private readonly paramTypes;
    /**
     * The return type associated with this call signature
     */
    private readonly returnType;
    /**
     * Construct a new call signature
     * @param paramTypes call parameter types
     * @param returnType call return type
     */
    constructor(paramTypes: IType[], returnType: IType);
    /**
     * Get the parameters of this call signature
     */
    params(): IType[];
    requiredParams(): number;
    /**
     * Get the return of this call signature
     */
    returns(): IType;
    /**
     * Get type parameters of this call signature
     */
    getTypeParameters(): IParametricType[];
    /**
     * Apply type arguments to this call signature
     * @param _ type arguments
     */
    apply(_: IType | Map<IType, IType>): ICallSignature;
    /**
     * Get a string representation of this call signature
     */
    toString(): string;
}
