import { OperatorKind, IParametricType, IType } from '../../types';
export declare class Operator<T extends IParametricType = IType> {
    /**
     * primarily used as part of the ITypeMappable interface
     */
    readonly name: string;
    /**
     * What operator kind associated with this operator
     */
    readonly operator: OperatorKind;
    /**
     * What is the other operand for this operator
     */
    readonly firstOperand: T;
    /**
     * What is the other operand for this operator
     */
    readonly secondOperand?: T;
    /**
     * What is the return type of this operator
     */
    readonly returnType: T;
    /**
     * Construct and instance of an operator
     * @param firstOperand What is the first operand
     * @param operator what is the operator kind
     * @param otherOperand what else need to appear in this operation
     * @param returnType what is the return type of this operation
     */
    constructor(firstOperand: T, operator: OperatorKind, returnType: T, otherOperand?: T);
    /**
     * Is the operator a unary operator
     */
    isUnary(): boolean;
}
