import { IParametricType, IType, TypeMap, ITypeMappable, IParametricIndexer } from '../types';
import { ParametricType } from '../models/parametricTypes/parametricType';
import { Type } from '../models/types/type';
import { VariadicType } from '../models/types/variadicType';
import { Indexer } from '../models/types/indexer';
/**
 * Create a type parameter type
 * @param name name of the placeholder
 */
export declare const createTypeParameter: (name: string) => ParametricType;
/**
 * Generate a new basic parametric type
 * @param name name of the new parametric type
 * @param typeParameterNames names of the type parameters
 */
export declare const createParametricType: (name: string, typeParameterNames: string[]) => ParametricType;
/**
 * Create a union type
 * @param isParameter is this union type a call parameter
 * @param types the types of the union
 */
export declare const createUnion: (isParameter: boolean, ...types: IType[]) => IType;
/**
 * Create an indexer
 * @param index the index type
 * @param returns the return type
 */
export declare const createIndexer: (index: IType, returns: IType) => Indexer;
/**
 * Create an parametric indexer
 * @param typeParameters type parameters for the indexer
 * @param index the index type
 * @param returns the return type
 */
export declare const createParametricIndexer: (typeParameters: string[], index: string | IParametricType, returns: string | IParametricType) => IParametricIndexer;
/**
 * Generate a new basic type
 * @param name name of the new type
 */
export declare const createType: (name: string) => Type;
/**
 * Generate a new parametric callable suffix type
 * @param name name of the suffix
 * @param returns return type of suffix call
 * @param params parameters of suffix call
 */
export declare const createParametricArgSuffixType: (name: string, typeParameters: string[], returns: string | IParametricType, ...params: (string | IParametricType)[]) => ParametricType;
/**
 * Generate a new callable suffix type
 * @param name name of the suffix
 * @param returns return type of suffix call
 * @param params parameters of suffix call
 */
export declare const createArgSuffixType: (name: string, returns: IType, ...params: IType[]) => Type;
/**
 * Generate a new get only suffix type
 * @param name name of the suffix
 * @param returns return type of suffix
 */
export declare const createSuffixType: (name: string, returns: IType) => Type;
/**
 * Generate a new get and set suffix type
 * @param name name of the suffix
 * @param returns return type of suffix
 */
export declare const createSetSuffixType: (name: string, returns: IType) => Type;
/**
 * Generates a new set only suffix type
 * @param name name of the suffix
 * @param returns return type of suffix
 */
export declare const createSetOnlySuffixType: (name: string, returns: IType) => Type;
/**
 * Generate a new callable variadic suffix type
 * @param name name of the suffix type
 * @param returns return type of suffix call
 * @param params variadic type of parameters
 */
export declare const createVarSuffixType: (name: string, returns: IType, params: IType) => Type;
/**
 * Generate a new function type
 * @param name name of the function
 * @param returns return type of function call
 * @param params parameters of function
 */
export declare const createFunctionType: (name: string, returns: IType, ...params: IType[]) => Type;
/**
 * Generate a new variadic function type
 * @param name name of the function
 * @param returns return type of function call
 * @param params variadic type of function call parameters
 */
export declare const createVarFunctionType: (name: string, returns: IType, params: IType) => Type;
/**
 * Create variadic type
 */
export declare const createVarType: (arg1: IType) => VariadicType;
/**
 * Create a type map with no parameter mapping
 * @param type type to map
 */
export declare const noMap: <T extends ITypeMappable<{}>>(type: T) => TypeMap<T>;
/**
 * Map a types parameters from a source to a target, assumes only one parameter
 * @param source source type
 * @param target target type
 */
export declare const mapTypes: <T1 extends ITypeMappable<{}>, T2 extends ITypeMappable<{}>>(source: T1, target: T2) => TypeMap<T2>;
