import { Diagnostic, DiagnosticSeverity, DiagnosticRelatedInformation, Range, Location } from 'vscode-languageserver';
import { DiagnosticUri } from '../types';
/**
 * This provides thin wrapper around Diagnostic.create where the server name is already included
 * @param range range the diagnostics applies
 * @param message message for the diagnostic
 * @param severity severity of the diagnostic
 * @param code error code for the diagnostic
 * @param relatedInformation other related information
 */
export declare const createDiagnosticUri: (location: Location, message: string, severity: DiagnosticSeverity, code: "invalid-property" | "invalid-value" | "scanner-error" | "parser-error" | "unable-to-load-file" | "unreachable-code" | "global-parameter" | "invalid-lazy-global" | "invalid-return-context" | "invalid-preserve-context" | "invalid-break-context" | "copy-deprecated" | "rename-deprecated" | "delete-deprecated" | "uninitialized-set" | "symbol-may-not-exist" | "symbol-may-not-runtime-exist" | "symbol-wrong-kind" | "symbol-unused-locally" | "symbol-unused" | "symbol-shadows" | "symbol-conflict" | "type-wrong" | "type-no-call" | "type-wrong-arity" | "type-list-invalid" | "type-no-indexer" | "type-not-function" | "type-missing" | "type-missing-suffix" | "type-missing-operator" | "type-no-setter" | "type-no-getter" | "directive-invalid-include", relatedInformation?: DiagnosticRelatedInformation[] | undefined) => DiagnosticUri;
/**
 * This provides a thin wrapper around Diagnostic.create where the server name is already included
 * @param range range the diagnostics applies
 * @param message message for the diagnostic
 * @param severity severity of the diagnostic
 * @param code error code for the diagnostic
 * @param relatedInformation other related information
 */
export declare const createDiagnostic: (range: Range, message: string, severity: DiagnosticSeverity, code: "invalid-property" | "invalid-value" | "scanner-error" | "parser-error" | "unable-to-load-file" | "unreachable-code" | "global-parameter" | "invalid-lazy-global" | "invalid-return-context" | "invalid-preserve-context" | "invalid-break-context" | "copy-deprecated" | "rename-deprecated" | "delete-deprecated" | "uninitialized-set" | "symbol-may-not-exist" | "symbol-may-not-runtime-exist" | "symbol-wrong-kind" | "symbol-unused-locally" | "symbol-unused" | "symbol-shadows" | "symbol-conflict" | "type-wrong" | "type-no-call" | "type-wrong-arity" | "type-list-invalid" | "type-no-indexer" | "type-not-function" | "type-missing" | "type-missing-suffix" | "type-missing-operator" | "type-no-setter" | "type-no-getter" | "directive-invalid-include", relatedInformation?: DiagnosticRelatedInformation[] | undefined) => Diagnostic;
/**
 * Code for each diagnostic in the language server
 */
export declare const DIAGNOSTICS: {
    readonly SCANNER_ERROR: "scanner-error";
    readonly PARSER_ERROR: "parser-error";
    readonly LOAD_ERROR: "unable-to-load-file";
    readonly UNREACHABLE_CODE: "unreachable-code";
    readonly GLOBAL_PARAMETER: "global-parameter";
    readonly INVALID_LAZY_GLOBAL: "invalid-lazy-global";
    readonly INVALID_RETURN_CONTEXT: "invalid-return-context";
    readonly INVALID_PRESERVE_CONTEXT: "invalid-preserve-context";
    readonly INVALID_BREAK_CONTEXT: "invalid-break-context";
    readonly COPY_DEPRECATED: "copy-deprecated";
    readonly RENAME_DEPRECATED: "rename-deprecated";
    readonly DELETE_DEPRECATED: "delete-deprecated";
    readonly UNINITIALIZED_SET: "uninitialized-set";
    readonly SYMBOL_MAY_NOT_EXIST: "symbol-may-not-exist";
    readonly SYMBOL_MAY_NOT_RUNTIME_EXIST: "symbol-may-not-runtime-exist";
    readonly SYMBOL_WRONG_KIND: "symbol-wrong-kind";
    readonly SYMBOL_UNUSED_LOCALLY: "symbol-unused-locally";
    readonly SYMBOL_UNUSED: "symbol-unused";
    readonly SYMBOL_SHADOWS: "symbol-shadows";
    readonly SYMBOL_CONFLICT: "symbol-conflict";
    readonly TYPE_WRONG: "type-wrong";
    readonly TYPE_NO_CALL: "type-no-call";
    readonly TYPE_WRONG_ARITY: "type-wrong-arity";
    readonly TYPE_LIST_INVALID: "type-list-invalid";
    readonly TYPE_NO_INDEXER: "type-no-indexer";
    readonly TYPE_NOT_FUNCTION: "type-not-function";
    readonly TYPE_MISSING: "type-missing";
    readonly TYPE_MISSING_SUFFIX: "type-missing-suffix";
    readonly TYPE_MISSING_OPERATOR: "type-missing-operator";
    readonly TYPE_NO_SETTER: "type-no-setter";
    readonly TYPE_NO_GETTER: "type-no-getter";
    readonly DIRECTIVE_INVALID_INCLUDE: "directive-invalid-include";
};
/**
 * Code for each diagnostic in `ksconfig.json`
 */
export declare const CONFIG_DIAGNOSTICS: {
    readonly INVALID_PROPERTY: "invalid-property";
    readonly INVALID_VALUE: "invalid-value";
};
