import { Graph } from '../models/graph';
import { StronglyConnectedComponent } from '../models/scc';
/**
 * Search the graph for strongly connected components. A strongly connected
 * component is a set of nodes that are reachable from all members of the component
 * @param graph graph to search for components
 */
export declare function scc<T>(graph: Graph<T>): StronglyConnectedComponent<T>;
/**
 * Perform depth first search on the provided graph
 * @param graph The graph to transpose
 * @param root root node to inspect
 */
export declare function dfsNode<T>(graph: Graph<T>, root: T): Dfs<T>;
/**
 * Perform depth first search on the provided graph. Updated the passed
 * visited array with visited nodes
 * @param graph graph
 * @param root index of the node to start from
 * @param visited visited nodes
 * @param whenVisited a function called when a node is visited.
 */
export declare function dfs<T>(graph: Graph<T>, root: T, visited: Set<T>, whenVisited?: (node: T) => Maybe<boolean>): void;
