import { KLS } from '../kls';
import { TextDocumentPositionParams, CompletionItem, SymbolInformation, MessageReader, MessageWriter, Diagnostic, DocumentSymbol } from 'vscode-languageserver';
import { KsBaseSymbol } from '../analysis/types';
import { CommanderStatic } from 'commander';
import { DiagnosticUri } from '../types';
import { IoKind } from '../services/ioService';
import { ParseError } from '../parser/models/parserError';
/**
 * Get the connection primitives based on the request connection type
 * @param connectionType connection type
 */
export declare const getConnectionPrimitives: (program: CommanderStatic) => {
    writer: MessageWriter;
    reader: MessageReader;
};
/**
 * Map a string to a case kind
 */
export declare const caseMapper: (key: string) => CaseKind;
/**
 * Map a string to a log level
 */
export declare const logMapper: (key: string) => LogLevel;
/**
 * Map of io kind to completion kind
 */
export declare const ioEntityMapper: (key: IoKind) => 17 | 19;
/**
 * Get a list of all symbols currently in scope at the given line
 * @param analyzer analyzer instance
 * @param documentPosition the current position in the document
 * @param keywordCompletions a list of keywords to always concat
 */
export declare const symbolCompletionItems: (analyzer: KLS, documentPosition: TextDocumentPositionParams, keywordCompletions: CompletionItem[]) => Promise<CompletionItem[]>;
/**
 * Get a list of all known suffixes give a suffix completion trigger
 * @param analyzer analyzer instance
 * @param documentPosition the current position in the document
 */
export declare const suffixCompletionItems: (analyzer: KLS, documentPosition: TextDocumentPositionParams) => Promise<CompletionItem[]>;
/**
 * Create lang server document symbols from ks symbols
 * @param analyzer analyzer instance
 * @param documentSymbol document identifier
 */
export declare function toSymbolInformation(entities: KsBaseSymbol[]): Maybe<SymbolInformation[]>;
export declare function toDocumentSymbol(entities: KsBaseSymbol[]): Maybe<DocumentSymbol[]>;
/**
 * Convert parser error to diagnostic
 * @param error parser error
 * @param uri uri string
 */
export declare const parseToDiagnostics: (error: ParseError, diagnostics?: DiagnosticUri[]) => DiagnosticUri[];
/**
 * convert resolver error to diagnostic
 * @param error diagnostic
 * @param uri uri string
 */
export declare const addDiagnosticsUri: (error: Diagnostic, uri: string) => DiagnosticUri;
