import { IExprVisitor, IStmtVisitor, IStmt, IExpr, ISuffixTermVisitor, ISuffixTerm } from '../parser/types';
import * as Decl from '../parser/models/declare';
import * as Stmt from '../parser/models/stmt';
import * as Expr from '../parser/models/expr';
import * as SuffixTerm from '../parser/models/suffixTerm';
export declare abstract class TreeTraverse implements IExprVisitor<() => void>, IStmtVisitor<() => void>, ISuffixTermVisitor<() => void> {
    constructor();
    protected stmtAction(stmt: IStmt): void;
    protected exprAction(expr: IExpr): void;
    protected suffixTermAction(suffixTerm: ISuffixTerm): void;
    visitDeclVariable(decl: Decl.Var): void;
    visitDeclLock(decl: Decl.Lock): void;
    visitDeclFunction(decl: Decl.Func): void;
    visitDeclParameter(decl: Decl.Param): void;
    visitStmtInvalid(_: Stmt.Invalid): void;
    visitBlock(stmt: Stmt.Block): void;
    visitExpr(stmt: Stmt.ExprStmt): void;
    visitOnOff(stmt: Stmt.OnOff): void;
    visitCommand(_: Stmt.Command): void;
    visitCommandExpr(stmt: Stmt.CommandExpr): void;
    visitUnset(_: Stmt.Unset): void;
    visitUnlock(_: Stmt.Unlock): void;
    visitSet(stmt: Stmt.Set): void;
    visitLazyGlobal(_: Stmt.LazyGlobal): void;
    visitIf(stmt: Stmt.If): void;
    visitElse(stmt: Stmt.Else): void;
    visitUntil(stmt: Stmt.Until): void;
    visitFrom(stmt: Stmt.From): void;
    visitWhen(stmt: Stmt.When): void;
    visitReturn(stmt: Stmt.Return): void;
    visitBreak(_: Stmt.Break): void;
    visitSwitch(stmt: Stmt.Switch): void;
    visitFor(stmt: Stmt.For): void;
    visitOn(stmt: Stmt.On): void;
    visitToggle(stmt: Stmt.Toggle): void;
    visitWait(stmt: Stmt.Wait): void;
    visitLog(stmt: Stmt.Log): void;
    visitCopy(stmt: Stmt.Copy): void;
    visitRename(stmt: Stmt.Rename): void;
    visitDelete(stmt: Stmt.Delete): void;
    visitRun(stmt: Stmt.Run): void;
    visitRunPath(stmt: Stmt.RunPath): void;
    visitRunPathOnce(stmt: Stmt.RunOncePath): void;
    visitCompile(stmt: Stmt.Compile): void;
    visitList(_: Stmt.List): void;
    visitEmpty(_: Stmt.Empty): void;
    visitPrint(stmt: Stmt.Print): void;
    visitExprInvalid(_: Expr.Invalid): void;
    visitTernary(expr: Expr.Ternary): void;
    visitBinary(expr: Expr.Binary): void;
    visitUnary(expr: Expr.Unary): void;
    visitFactor(expr: Expr.Factor): void;
    visitSuffix(expr: Expr.Suffix): void;
    visitLambda(expr: Expr.Lambda): void;
    visitSuffixTermInvalid(_: SuffixTerm.Invalid): void;
    visitSuffixTrailer(suffixTerm: SuffixTerm.SuffixTrailer): void;
    visitSuffixTerm(suffixTerm: SuffixTerm.SuffixTerm): void;
    visitCall(suffixTerm: SuffixTerm.Call): void;
    visitHashIndex(_: SuffixTerm.HashIndex): void;
    visitBracketIndex(suffixTerm: SuffixTerm.BracketIndex): void;
    visitDelegate(_: SuffixTerm.Delegate): void;
    visitLiteral(_: SuffixTerm.Literal): void;
    visitIdentifier(_: SuffixTerm.Identifier): void;
    visitGrouping(suffixTerm: SuffixTerm.Grouping): void;
}
